.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.00",
.\"     date            = "02 October 1996",
.\"     time            = "05:16:08 MDT",
.\"     filename        = "authidx.man",
.\"     address         = "Center for Scientific Computing
.\"                        Department of Mathematics
.\"                        University of Utah
.\"                        Salt Lake City, UT 84112
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "03078 572 2231 15012",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@ieee.org (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "author/editor index, BibTeX, bibliography",
.\"     supported       = "yes",
.\"     docstring       = "This is the UNIX manual page file for
.\"                        authidx, a program for creating
.\"                        author/editor indexes from citations of
.\"                        BibTeX bibliography entries.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH AUTHIDX 1 "02 October 1996" "Version 1.00"
.if t .ds Bi B\s-2IB\s+2T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Bi BibTeX
.if t .ds La LaT\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds La LaTeX
.if t .ds Ps P\s-2OST\s+2S\s-2CRIPT\s+2
.if n .ds Ps PostScript
.if t .ds Te T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Te TeX
.hw Post-Script
.\"===============================================
.SH NAME
authidx \- a tool for creating author/editor index files from citations \
of BibTeX file entries
.\"===============================================
.SH SYNOPSIS
authidx
.BR "[\ MAXNAME" =nnn "\ ]"
.BR "[\ ROTATE" =n "\ ]"
.BR "[\ SEE" =nnn "\ ]"
.IB *.aei "\ \ \ >\ " output-ida-file
.PP
and
.PP
authidx
.BR "[\ MAXNAME" =nnn "\ ]"
.BR "[\ ROTATE" =n "\ ]"
.BR "[\ SEE" =nnn "\ ]"
.I "*.aei bbl-file \ \ \ >\ output-new-bbl-file"
.\"===============================================
.SH DESCRIPTION
.B authidx
processes one or more
.I .aei
(author/editor index) files, or
.I stdin
if no input files are named on the command line,
to produce on
.I stdout
a
.I .ida
index file that can either be logically merged
with the original
.I .idx
file (for a combined author/editor and subject
index), or processed independently by an indexing
program, such as
.BR makeindex (1),
.BR texidx (1),
or
.BR texindex (1),
to produce a separate author/editor index.
.PP
Alternatively, if a \*(Bi\&
.I .bbl
formatted bibliography file is given
.I following
the index files on the command line, then the
output will instead be a new
.I .bbl
file with citation page references inserted at the
end of each bibliography entry.  This alternative
provides a compact mini-index embedded in the
bibliography, but loses the convenience to the
reader of being able to locate quickly a reference
to a publication by a particular person.
Nevertheless, it may be convenient when space is
at a premium, such as in journal articles.
.PP
.B authidx
assumes that \*(Bi\& files have a consistent form
such as that guaranteed by
.BR bibclean (1),
in order to permit simple pattern matching for
parsing \*(Bi\& entries.
.PP
A typical use with
.BR makeindex (1)
looks like this:
.RS
.nf
.BI authidx " mybook.aei > mybook.ida"
.fi
.RE
Then, for separate author/editor and subject indexes:
.RS
.nf
.BI "makeindex -o" " mybook.ina mybook.ida"
.BI "makeindex -o" " mybook.ind mybook.idx"
.fi
.RE
or for a single combined index:
.RS
.nf
.BI "makeindex -o" " mybook.ind mybook.idx mybook.ida"
.PP
.fi
.RE
The required
.I .aei
files are produced from a \*(La\& file that
incorporates the
.I authidx
style option, and issues the
.I \emakeauthoreditorindex
command in the preamble.
.PP
If a separate author/editor index is wanted,
then the \*(La\& file should have a
.I \eprintauthoreditorindex
command where the index is required (usually near
the end, either before or after the
.I \eprintindex
command).  The contents of the
.I .ina
file produced by the indexing program will be read
at that point.
.PP
If a combined index is required, then only the
.I \eprintindex
command is needed.
.PP
Here is an outline of a suitable \*(La\& 2.09
input file:
.RS
.nf
.I \edocumentstyle[authidx]{book}
.I \emakeauthoreditorindex
.I \emakeindex
.I \ebegin{document}
.I .\|.\|.
.I \eprintauthoreditorindex
.I \eprintindex
.I \eend{document}
.fi
.RE
For \*(La\& 2e in native 2e mode, replace the first line by
.RS
.nf
.I \edocumentclass{book}
.I \eusepackage{authidx}
.fi
.RE
Assuming
.BR makeindex (1)
as the indexing program, the document can be
typeset like this:
.RS
.nf
.BI latex " mybook.ltx"
.BI bibtex " mybook"
.BI latex " mybook.ltx"
.BI bibtex " mybook"
.BI authidx " mybook.aei > mybook.ida"
.BI "makeindex -o" " mybook.ina mybook.ida"
.BI "makeindex -o" " mybook.ind mybook.idx"
.BI latex " mybook.ltx"
.fi
.RE
.\"===============================================
.SH OPTIONS
.B authidx
options take the form of
.BI NAME =value
assignments, rather than the more usual
hyphen-prefixed options common in other UNIX
utilities.  If an option is given more than once,
its
.I last
assigned value is used.
.TP \w'\fBMAXNAME\fP\fI=nnn\fP'u+3n
.BI MAXNAME =nnn
The
.BI MAXNAME =nnn
option can be used to limit which author/editor
names are indexed.
.BI MAXNAME =1
indexes only the first of them,
.BI MAXNAME =2
indexes the first and second, and so on.  The
default is
.BI MAXNAME =infinity,
for indexing all names.
.TP
.BI ROTATE =n
A non-zero value of the
.BI ROTATE =n
option requests generation of rotated multi-part
names in the index, so that an author like
.I "Madrid, Jorge de la"
will produce cross-referenced entries for
.I "la Madrid, Jorge de"
and
.IR "de la Madrid, Jorge" .
Since conventions about alphabetizing of
multi-part names depend on language and culture,
and since many scientific and literary
bibliographies are international in nature, it is
a convenience to the reader to be able to find a
name under any of the rotated forms, so the
default is
.BI ROTATE =1.
To suppress generation of the rotated index entries,
use
.BI ROTATE =0.
.IP
It is possible that name rotation will produce
some additional unexpected entries in your index.
Consider these three names:
.RS
.TP
\(bu
.I "Donald Ervin Knuth"
.TP
\(bu
.I "Per Brinch Hansen"
.TP
\(bu
.I "Federico Garcia Lorca"
.RE
.IP
In the first of these names,
.I Ervin
is just a middle name, and one that that
particular author always abbreviates to an initial
in his publications, and it should therefore not
rate an index entry under
.IR "Ervin Knuth" ,
even though
.B authidx
will generate one.  In the second,
.I Brinch
is a middle name that is generally used in
combination with the last name to distinguish that
author from the large number of other people with
one of the commonest Danish surnames, so
both
.I "Brinch Hansen, Per"
and
.I "Hansen, Per Brinch"
index entries are desirable.  In the third,
.I Garcia
is the Spanish author's paternal name which, for
him, is generally used with the maternal name,
.IR Lorca ,
because the latter is less common.
.IP
A computer program cannot distinguish between the
indexing expectations that you might have for each
of these three authors, so
.B authidx
takes the view that it should consistently index
all rotations of their names, since a few more
index entries is better than too few.
Nevertheless, you can limit the indexing by
addition of suitable bracing: if the \*(Bi\& file
contains
.RS
.nf
\fIauthor\ =\ "{Donald Ervin} Knuth",\fP
\fIauthor\ =\ "Per {Brinch Hansen}"\fP
\fIauthor\ =\ "Federico {Garcia Lorca}"\fP
.fi
.RE
.IP
then index rotations of those names will be
suppressed.
.TP
.BI SEE =nnn
The
.BI SEE =nnn
option can be used to control cross-references
from second, third, .\|.\|. author/editor names
to the first author/editor name.
.BI SEE =0
suppresses such cross-referencing;
.BI SEE =2
cross-references only the second author/editor;
.BI SEE =3
cross-references the second and third, and so on.
The default is
.BI SEE =infinity,
for complete cross-referencing.
.\"===============================================
.SH "INDEX CUSTOMIZATION"
You can customize the appearance of author/editor
index entries by supplying suitable redefinitions
of four \*(Te\& macros that encapsulate index
entries, after the
.I authidx.sty
file, which defines them initially, is processed.
Their default definitions are:
.RS
.nf
.I "\edef \eAEnamefontfirst #1{{\esc #1}}"
.I "\edef \eAEnamefontrest  #1{{\erm #1}}"
.I "\edef \eAEpagefontfirst #1{{\ebf #1}}"
.I "\edef \eAEpagefontrest  #1{{\erm #1}}"
.fi
.RE
The first author/editor name in each bibliography
entry is typeset by
.IR \eAEnamefontfirst ,
and remaining names are typeset by
.IR \eAEnamefontrest .
Similarly, the page number of an entry for the
first author/editor name is typeset by
.IR \eAEpagefontfirst ,
and the page numbers of entries for remaining
names are typeset by
.IR \eAEpagefontrest .
Using different fonts for the first and rest parts
allows the reader to readily distinguish between
the contributions of
.I Smith
and
.IR "et al." .
.PP
The default definitions of these font macros do
not specify a font
.IR size ,
so in \*(La\&, they will automatically inherit the
prevailing font size.  This allows you to use
\*(La\& input like this:
.RS
.nf
.I "\ebegin{small}"
.I "  \eprintauthoreditorindex"
.I "  \eprintindex"
.I "\eend{small}"
.fi
.RE
to typeset the indexes in smaller type, as is
commonly done.
.PP
When a
.I .bbl
file is supplied on the command line,
.B authidx
produces a new
.I .bbl
file in which each bibliography entry is augmented
by a call to the
.I \ebibindex
macro, giving it a list of page numbers on which
the bibliography entry is cited.  The default
definition of this macro
.RS
.nf
.I "\edef \ebibindex #1{\e{{\ebf #1}\e}}"
.fi
.RE
provided by the
.I authidx.sty
file typesets the page numbers as a braced
boldface list.
.PP
You can provide an alternate definition of this
macro if you wish, anywhere between the use of
.I authidx.sty
and the
.I \ebibliography{bibfile1,bibfile2,.\|.\|.,bibfilen}
command in your \*(La\& file.
.\"===============================================
.SH BUGS
I need to add an option to control the handling of
.IR Jr. -like
suffixes.  The current version implements the
recommendations of
.IR "The Chicago Manual of Style" ,
(14th ed., 1995, University of Chicago Press,
Chicago, IL, USA, ISBN 0-226-10389-7), and
.IR "The MLA Handbook for Writers of Research Papers" ,
(4th ed., 1995, Modern Language Association of
America, New York, NY, USA, ISBN 0-87352-565-5),
moving
.IR Jr. -like
suffixes to the end of the inverted name, as in
the index entries
.RS
.nf
.I "Bach, P. D. Q., Jr., 123\(en125, 203"
.I "Rockefeller, John D., III, 17, 29\(en32"
.fi
.RE
.PP
I need to implement an option to index the
bibliography items themselves, by redefining
.I \ebibitem
to output an index entry to the
.I .aei
file.
.PP
For production of
.I .bbl
file mini-indexes,
.B authidx
currently only handles simple page numbers that
are lower-case roman numerals, arabic numbers, or
upper-case roman numerals, and sorts them in that
order.  Composite page numbers (127a, A.1, C-123,
II-D-23, .\|.\|.) of the type supported by
.BR makeindex (1)
will not be sorted properly, or collapsed into
page ranges, by
.BR authidx .
Also, unlike
.BR makeindex (1),
.B authidx
does not support user customization of the sort
order.
.PP
Finally, the
.I authidx.sty
file needs to be extended so that it can be used
with plain \*(Te\& and AmS\*(Te\& as well.
.\"===============================================
.SH "ENVIRONMENT VARIABLES"
.TP \w'\fIBIBINPUTS\fP'u+3n
.I BIBINPUTS
A colon-separated list of directory names
used by
.BR bibtex (1)
and
.B authidx
to locate \*(Bi\& bibliography files named in the
.I \ebibdata
command in the
.I .aei
and
.I .aux
files.
.\"===============================================
.SH FILES
.TP \w'\fI*.mmm\fP'u+3n
.I *.aei
Author/editor citation index files containing index entries
of the form
.RS
.nf
.I "\eindexentry{label1,label2,.\|.\|.,labeln}{pagenumber}
.fi
.RE
.IP
plus a single
.IP
.RS
.nf
.I "\ebibdata{bibfile1,bibfile2,.\|.\|.,bibfilen}
.fi
.RE
.IP
command naming the \*(Bi\& bibliography files
needed to resolve the citations.  The index
entries are produced by an internal \*(La\&
citation command that is called by user-level
citation commands, such as
.IR \ecite ,
.IR \eshortcite ,
.IR \eciteA ,
.IR \eciteANP ,
.IR \eciteN ,
.IR \eciteNP ,
.IR \eciteyear ,
.IR \eciteyearNP ,
.IR \eshortcite ,
.IR \eshortciteA ,
.IR \eshortciteANP ,
.IR \eshortciteN ,
and
.IR \eshortciteNP .
The kinds of citation commands available depend on
the
.I \ebibliographystyle
chosen; only
.I \ecite
is available in all bibliography styles.
.TP
.I *.bbl
Formatted bibliography files produced by \*(Bi\&
from citation requests recorded in
.I *.aux
files, bibliography styles defined in
.I *.bst
files, and \*(Bi\& bibliography database files.
.B authidx
does not read
.I *.bst
or
.I *.aux
files.
.TP
.I *.bib
\*(Bi\& bibliography database files.
.TP
.I *.ida
Author/editor index files produced by
.BR authidx .
These must be processed by an indexing program to
produce the final author/editor index.
.\"===============================================
.SH AVAILABILITY
The master source distribution for
.B authidx
is maintained at the Internet archive location
.IR ftp://ftp.math.utah.edu/pub/misc/index.html#authidx-1.00
for both anonymous ftp and World-Wide Web access.
The source code is in the public domain, and
copies of the program may be freely distributed
and used for any purpose.
.\"===============================================
.SH "SEE ALSO"
.BR bibclean (1),
.BR bibtex (1),
.BR latex (1),
.BR makeindex (1),
.BR tex (1).
.BR texidx (1),
.BR texindex (1).
.\"===============================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
University of Utah
Department of Mathematics, 105 JWB
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP, \fCbeebe@ieee.org\fP (Internet)
WWW URL: \fChttp://www.math.utah.edu/~beebe\fP
.fi
.\"===============================================
.\" This is for GNU Emacs file-specific customization:
.\" Local Variables:
.\" fill-column: 50
.\" End:
